# qCrawl Documentation

qCrawl is a fast async web crawling & scraping framework for python, used to crawl websites and extract structured data from their pages.
It can be applied to various tasks, such as data mining, monitoring, and automated testing.


<div class="grid cards" markdown>

-   :material-clock-fast:{ .lg .middle } __Start in 5 minutes__

    ---

    Install `qcrawl` for your favorite OS and get up
    and running in minutes.

    [:octicons-arrow-right-24: Getting started](getting-started/overview.md)

-   :fontawesome-solid-square-binary:{ .lg .middle } __Blazing fast__

    ---

    Async-first design, efficient downloader, high-performance backends, and fine-grained concurrency controls.

    [:octicons-arrow-right-24: Architecture](extending/architecture_overview.md)

-   :material-star-plus:{ .lg .middle } __Helpful community__

    ---

    Join our Discord community and get answers to your web scraping questions.


    [:octicons-arrow-right-24: Let us dig](https://discord.gg/yT54ff6STY)

-   :material-download:{ .lg .middle } __Get qCrawl__

    ---

    QCrawl is licensed under MIT and available on GitHub, PyPI, Conda Forge and as OS packages.

    [:octicons-arrow-right-24: Installation](getting-started/installation.md)

</div>
